"""ZPhotoSlides Folder
"""
from Globals import Persistent
from Globals import package_home
from OFS.ObjectManager import ObjectManager
from OFS.SimpleItem import Item
from OFS.PropertyManager import PropertyManager
from OFS.FindSupport import FindSupport
from AccessControl.Role import RoleManager
from AccessControl import ClassSecurityInfo
from Globals import MessageDialog
from Globals import InitializeClass, DTMLFile,HTMLFile
from ZPhotoSlides import ZPhotoSlides
from Products.ZCatalog.ZCatalog import ZCatalog
import os
import string

try:
	from Products.Localizer import LocalDTMLFile
	from Products.Localizer import Gettext
	gettext = Gettext.translation(globals())
except:
	have_localizer = 0
	from Globals import DTMLFile
	LocalDTMLFile = DTMLFile
	del DTMLFile
else:
	have_localizer = 1

if(not have_localizer):
	from utils import gettext
_ = gettext

def upload_file(path,_prefix=None):
        if _prefix is None: _prefix=SOFTWARE_HOME
        elif type(_prefix) is not type(''):
            _prefix=package_home(_prefix)
        path = os.path.join(_prefix, path)

        file=open(path, 'rb')
        data=file.read()
        file.close()
        return data

class ZPhotoSlidesFolder(
                         ObjectManager,
                         PropertyManager,
                         RoleManager,
                         Item,
                         FindSupport):
    """ZPhotoSlides Folder object implementation."""
    if(have_localizer):
    	locale = package_home(globals()) + '/locale/'
    	_gettext = gettext

    manage_options = (
                       {'label': "Manage ZPhotoSlides",    'action':'manage_main'},
	                 {'label': "Properties",       'action': 'manage_props'},
                       {'label': "Edit layout", 'action': 'user_layout_folder'},
		           {'label': "View",       'action': 'index_html'},
		           {'label': "About this product",   'action': 'about'},
                       {'label': "Security",   'action': 'manage_access'},
                       {'label': "Undo", 'action': 'manage_UndoForm'},
                       {'label': "Ownership", 'action': 'manage_owner'}
		     )
 
    meta_type = "ZPhotoSlides Folder"
    index_html = LocalDTMLFile('dtml/index_folder_html',globals(),gettext=gettext)
    manage_tabs = LocalDTMLFile('dtml/manage_tabs',globals(),gettext=gettext)
    manage_props = LocalDTMLFile('dtml/ZPhotoSlidesFolderEdit',globals(),gettext=gettext) # edit main properties
    user_layout_folder = LocalDTMLFile('dtml/user_layout_folder',globals(),gettext=gettext)
    about = LocalDTMLFile('dtml/about',globals(),gettext=gettext)                         # about us
    css_file = HTMLFile('dtml/stylesheet_demo.css',globals(),gettext=gettext)        # main css file
    manage_main = LocalDTMLFile('dtml/list_zphotoslides',globals(),gettext=gettext)
    
    _properties = (
        {'id':'title', 'type': 'string', 'mode': 'w'},
        )

    security=ClassSecurityInfo()

    def __init__(self, id, title, description):

        self.version = '0.3'
        self.id = id
        self.title = title
        self.description = description
        self.actual_css = 'stylesheet_base_css'
        self.update_date = '10/01/2003'
        self.zphoto_header_folder= ''                  # get content of standard header Folder
        self.zphoto_footer_folder= ''                  # get content of standard header Folder
        self.keywords = ''                      # keywords describing the object
        self.description = ''                   # description of the object
        self.manage_addFolder('css', 'Thumbnails', createPublic=0, createUserF=0, REQUEST=None)
	catalog = ZCatalog('catalog',container=self)
	self._setObject('catalog', catalog)
	self.manage_catalog()
	self.css._setProperty('amount_css',1,'int')
	self.css.manage_addDTMLMethod('stylesheet_base_css', 'Main ZPhotoSlidesFolder Stylesheet', upload_file('dtml/stylesheet_demo.css.dtml', globals()), REQUEST=None)

    def manage_catalog(self):
	try:    #for 2.5 ZCatalog which add automaticaly id and title
		self.catalog.manage_delIndex(ids=['id','title'])
	except:
		pass
	self.catalog.addIndex('id','FieldIndex')
	self.catalog.addIndex('title','TextIndex')

    def reCatalog(self, REQUEST=None):
	"""clear the catalog, and put all images into it."""
        self.catalog._catalog.clear()
        path='/'+string.split(REQUEST.URL1, REQUEST.SERVER_URL)[1][1:]
	self.catalog.ZopeFindAndApply(self, obj_metatypes=['Image'], search_sub=1,REQUEST=REQUEST, apply_func=self.catalog.catalog_object, apply_path=path)

    def update_catalog_index(self):
	"update the index of the catalog"
	self.catalog.manage_reindexIndex(['id','title'])

    security.declareProtected('View management screens', 'upgrade')
    def upgrade(self,REQUEST):
	"Allow the user to Upgrade to the new ZPhotoSlides Folder"
	if(self.version == '0.2'):
		self.zphoto_header_folder= ''
		self.zphoto_footer_folder= ''
		try:
			del self.index_html
#			self.index_html = LocalDTMLFile('dtml/index_folder_html',globals(),gettext=gettext)
		except:
			pass
		self.keywords = ''
		self.version = '0.3'
#		index_folder_html = DTMLFile('dtml/index_folder_html', globals())
#		self.manage_addDTMLMethod('index_html', '')
#		self._getOb('index_html').manage_edit(index_folder_html, 'Sample Folder View')

    security.declareProtected('Access contents information', 'zphotoslidesIds')
    def manage_edit(self, title,description,REQUEST):
        """Edit the main properties..."""
        self.title = title
        self.description = description
        if REQUEST is not None:
            return MessageDialog(
                title = _("Edited"),
                message = _("Properties for") + " %s " % self.id + _("changed"),
                action = './manage_props',
                )

    security.declareProtected('Access contents information', 'zphotoslidesIds')
    def zphotoslidesIds(self):
        """Return list of ZPhotoSlides in this folder."""
        return self.objectIds(['ZPhotoSlides'])

    def image_select(self):
        return [''] + self.photoIds()

    security.declareProtected('Access contents information', 'numZPhotoSlides')
    def numZPhotoSlides(self):
        """Return number of ZPhotoSlides in folder tree."""
        ZPhotoSlides = len(self.objectIds(['ZPhotoSlides']))
        for folder in self.objectValues(['ZPhotoSlides Folder']):
            ZPhotoSlides = ZPhotoSlides + folder.numZPhotoSlides()
        return ZPhotoSlides

    def numZPhotoSlidesFolder(self):
	nbr = len(self.objectIds(['ZPhotoSlides Folder']))
	for folder in self.objectValues(['ZPhotoSlides Folder']):
            nbr = nbr + folder.numZPhotoSlidesFolder()
	return nbr

    def numPhotos(self):
	"return the number of photos inside all the ZPhotoSlides of the folder"
	sum = 0
	for zphoto in self.objectValues('ZPhotoSlides'):
		sum = sum + zphoto.non_hidden_pic
	return sum

    def give_header_4_robots(self):
	"give the header for the robots"
	return """
<meta name="KEYWORDS" content="%s" />
<meta name="DESCRIPTION" content="%s" />
<meta name="resource-type" content="document" />
<meta name="ROBOTS" content="INDEX,FOLLOW" />
<meta http-equiv="expires" content="0" />
<meta name="author" content="ZPhotoSlides Folder" />
<meta name="copyright" content="ZPhotoSlides Folder %s" />
<meta name="revisit-after" content="1 days" />
<meta name="rating" content="General" />""" % (self.keywords,self.description,self.version)

    security.declareProtected('View management screens','new_header_footer_folder')
    def new_header_footer_folder(self,REQUEST):
	"Change the standard_html_header and footer Folder"
	self.zphoto_header_folder = REQUEST.header
	self.zphoto_footer_folder = REQUEST.footer
	if(REQUEST.header != '' or REQUEST.footer != ''):
                msg1 = _("""You use yet the standard html footer and header. To use the css files again
                make the standard html footer and header <u><i>EMPTY</i></u> in the layout formular!""")
                title_1 = "Using standard html header and footer"
        else:
		msg1 = _("You use yet the CSS file.")
		title_1 = _("Using CSS file")
	return self.REQUEST.RESPONSE.redirect('%s/user_layout_folder?message1=%s&message_title=%s' % (REQUEST.URL1, msg1, title_1))

    security.declareProtected('Access contents information', 'nextZPhotoSlidesFolder')
    def nextZPhotoSlidesFolder(self):
        """Return next ZPhotoSlides Folder."""
        id = self.getId()
        folderIds = self.aq_parent.objectIds(['ZPhotoSlides Folder'])
        folderIds.sort()
        if id == folderIds[-1]:
            return None
        return getattr(self.aq_parent, folderIds[folderIds.index(id)+1])

    security.declareProtected('Access contents information', 'prevZPhotoSlidesFolder')
    def prevZPhotoSlidesFolder(self):
        """Return previous ZPhotoSlides Folder."""
        id = self.getId()
        folderIds = self.aq_parent.objectIds(['ZPhotoSlides Folder'])
        folderIds.sort()
        if id == folderIds[0]:
            return None
        return getattr(self.aq_parent, folderIds[folderIds.index(id)-1])

manage_addZPhotoSlidesFolderForm = LocalDTMLFile('dtml/addZPhotoSlidesFolderForm', globals(),gettext=gettext)

def manage_addZPhotoSlidesFolder(dispatcher, id, title,description, REQUEST=None):
    """Add ZPhotoSlides Folder object"""
    dest = dispatcher.Destination()
    dest._setObject(id, ZPhotoSlidesFolder(id, title,description))
    self = dest._getOb(id)

    if REQUEST is not None:
        try:    url=dispatcher.DestinationURL()
        except: url=REQUEST['URL1']
        REQUEST.RESPONSE.redirect('%s/%s/manage_props' % (url,id))
    return id

InitializeClass(ZPhotoSlidesFolder)
